# NATools - Package with parallel corpora tools
# Copyright (C) 2002-2004  Alberto Simes
#
# This package is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

package NAT::Corpus;

use 5.006;
use strict;
use warnings;
use Data::Dumper;
require Exporter;

use NAT;

our @ISA = qw(Exporter);
our %EXPORT_TAGS = ( 'all' => [ qw() ] );
our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
our @EXPORT = qw();

our $VERSION = '0.02';

sub new {
  my $filename = shift;
  return undef unless -f $filename;

  my $self;
  my $id = NAT::corpus_open($filename);
  return undef if $id < 0;

  $self->{id} = $id;
  return bless $self #amen
}

sub sentences_nr {
  my $self = shift;

  if (!$self->{nrsentences}) {
    $self->{nrsentences} = NAT::corpus_sentences_nr_xs($self->{id});
  }

  return $self->{nrsentences}
}

sub iterator {
  my $self = shift;
  return NAT::Corpus::Iterator::new($self);
}

sub first_sentence {
  my $self = shift;
  return NAT::corpus_first_sentence_xs($self->{id});
}

sub next_sentence {
  my $self = shift;
  return NAT::corpus_next_sentence_xs($self->{id});
}

sub free {
  my $self = shift;
  NAT::corpus_free_xs($self->{id});
}

package NAT::Corpus::Iterator;

sub new {
  my $corpusObject = shift;
  my $self = { corpus => $corpusObject };
  my $fs = $self->{corpus}->first_sentence;
  $self->{csentence} = $fs;
  return bless $self #amen
}

sub next {
  my $self = shift;
  my $sentence = $self->{csentence};
  if ($sentence) {
    my $fs = $self->{corpus}->next_sentence;
    $self->{csentence} = $fs;
  }
  return $sentence;
}



1;
__END__

=head1 NAME

NAT::Corpus - Perl extension to inter-operate with Corpus files

=head1 SYNOPSIS

  use NAT::Corpus;

  $corpus = NAT::Corpus::new("crp1");

=head1 DESCRIPTION

=head1 SEE ALSO

To use the parallel corpus (search sentences and so one) use the
NAT::PCorpus module.

See perl(1) and NATools documentation.

=head1 AUTHOR

Alberto Manuel Brandao Simoes, E<lt>albie@alfarrabio.di.uminho.ptE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2002-2009 by NATURA Project
http://natura.di.uminho.pt

This library is free software; you can redistribute it and/or modify
it under the GNU General Public License 2, which you should find on
parent directory. Distribution of this module should be done including
all NATools package, with respective copyright notice.

=cut
